@@ -18,7 +18,7 @@
 #define ZDICT_STATIC_LINKING_ONLY
 
 #ifdef ZSTD_SINGLE_FILE
-#include <zstdlib.c>
+#include <zstd.c>
 
 /* We use private APIs from pool.h. We can't rely on availability
    of this header or symbols when linking against the system libzstd.
@@ -29,8 +29,9 @@
 #include <zstd.h>
 #endif
 
-/* Remember to change the string in zstandard/__init__.py, rust-ext/src/lib.rs as well */
-#define PYTHON_ZSTANDARD_VERSION "0.15.2"
+/* Remember to change the string in zstandard/__init__.py, rust-ext/src/lib.rs,
+   and debian/changelog as well */
+#define PYTHON_ZSTANDARD_VERSION "0.24.0"
 
 typedef enum {
     compressorobj_flush_finish,
@@ -46,7 +47,7 @@ typedef struct {
     PyObject_HEAD ZSTD_CCtx_params *params;
 } ZstdCompressionParametersObject;
 
-extern PyTypeObject ZstdCompressionParametersType;
+extern PyTypeObject *ZstdCompressionParametersType;
 
 /*
    Represents a FrameParameters type.
@@ -60,7 +61,7 @@ typedef struct {
     char checksumFlag;
 } FrameParametersObject;
 
-extern PyTypeObject FrameParametersType;
+extern PyTypeObject *FrameParametersType;
 
 /*
    Represents a ZstdCompressionDict type.
@@ -86,7 +87,7 @@ typedef struct {
     ZSTD_DDict *ddict;
 } ZstdCompressionDict;
 
-extern PyTypeObject ZstdCompressionDictType;
+extern PyTypeObject *ZstdCompressionDictType;
 
 /*
    Represents a ZstdCompressor type.
@@ -105,7 +106,7 @@ typedef struct {
     ZSTD_CCtx_params *params;
 } ZstdCompressor;
 
-extern PyTypeObject ZstdCompressorType;
+extern PyTypeObject *ZstdCompressorType;
 
 typedef struct {
     PyObject_HEAD
@@ -115,7 +116,7 @@ typedef struct {
     int finished;
 } ZstdCompressionObj;
 
-extern PyTypeObject ZstdCompressionObjType;
+extern PyTypeObject *ZstdCompressionObjType;
 
 typedef struct {
     PyObject_HEAD
@@ -126,13 +127,13 @@ typedef struct {
     size_t outSize;
     int entered;
     int closing;
-    int closed;
+    char closed;
     int writeReturnRead;
     int closefd;
     unsigned long long bytesCompressed;
 } ZstdCompressionWriter;
 
-extern PyTypeObject ZstdCompressionWriterType;
+extern PyTypeObject *ZstdCompressionWriterType;
 
 typedef struct {
     PyObject_HEAD
@@ -151,7 +152,7 @@ typedef struct {
     PyObject *readResult;
 } ZstdCompressorIterator;
 
-extern PyTypeObject ZstdCompressorIteratorType;
+extern PyTypeObject *ZstdCompressorIteratorType;
 
 typedef struct {
     PyObject_HEAD
@@ -163,7 +164,7 @@ typedef struct {
     int closefd;
 
     int entered;
-    int closed;
+    char closed;
     unsigned long long bytesCompressed;
 
     ZSTD_inBuffer input;
@@ -173,7 +174,7 @@ typedef struct {
     PyObject *readResult;
 } ZstdCompressionReader;
 
-extern PyTypeObject ZstdCompressionReaderType;
+extern PyTypeObject *ZstdCompressionReaderType;
 
 typedef struct {
     PyObject_HEAD
@@ -186,7 +187,7 @@ typedef struct {
     size_t chunkSize;
 } ZstdCompressionChunker;
 
-extern PyTypeObject ZstdCompressionChunkerType;
+extern PyTypeObject *ZstdCompressionChunkerType;
 
 typedef enum {
     compressionchunker_mode_normal,
@@ -201,7 +202,7 @@ typedef struct {
     CompressionChunkerMode mode;
 } ZstdCompressionChunkerIterator;
 
-extern PyTypeObject ZstdCompressionChunkerIteratorType;
+extern PyTypeObject *ZstdCompressionChunkerIteratorType;
 
 typedef struct {
     PyObject_HEAD
@@ -212,17 +213,19 @@ typedef struct {
     ZSTD_format_e format;
 } ZstdDecompressor;
 
-extern PyTypeObject ZstdDecompressorType;
+extern PyTypeObject *ZstdDecompressorType;
 
 typedef struct {
     PyObject_HEAD
 
         ZstdDecompressor *decompressor;
     size_t outSize;
+    int readAcrossFrames;
     int finished;
+    PyObject *unused_data;
 } ZstdDecompressionObj;
 
-extern PyTypeObject ZstdDecompressionObjType;
+extern PyTypeObject *ZstdDecompressionObjType;
 
 typedef struct {
     PyObject_HEAD
@@ -243,7 +246,7 @@ typedef struct {
     /* Whether the context manager is active. */
     int entered;
     /* Whether we've closed the stream. */
-    int closed;
+    char closed;
 
     /* Number of bytes decompressed and returned to user. */
     unsigned long long bytesDecompressed;
@@ -260,7 +263,7 @@ typedef struct {
     int finishedOutput;
 } ZstdDecompressionReader;
 
-extern PyTypeObject ZstdDecompressionReaderType;
+extern PyTypeObject *ZstdDecompressionReaderType;
 
 typedef struct {
     PyObject_HEAD
@@ -270,12 +273,12 @@ typedef struct {
     size_t outSize;
     int entered;
     int closing;
-    int closed;
+    char closed;
     int writeReturnRead;
     int closefd;
 } ZstdDecompressionWriter;
 
-extern PyTypeObject ZstdDecompressionWriterType;
+extern PyTypeObject *ZstdDecompressionWriterType;
 
 typedef struct {
     PyObject_HEAD
@@ -294,7 +297,7 @@ typedef struct {
     int finishedOutput;
 } ZstdDecompressorIterator;
 
-extern PyTypeObject ZstdDecompressorIteratorType;
+extern PyTypeObject *ZstdDecompressorIteratorType;
 
 typedef struct {
     int errored;
@@ -317,7 +320,7 @@ typedef struct {
     Py_ssize_t segmentCount;
 } ZstdBufferSegments;
 
-extern PyTypeObject ZstdBufferSegmentsType;
+extern PyTypeObject *ZstdBufferSegmentsType;
 
 typedef struct {
     PyObject_HEAD
@@ -328,7 +331,7 @@ typedef struct {
     unsigned long long offset;
 } ZstdBufferSegment;
 
-extern PyTypeObject ZstdBufferSegmentType;
+extern PyTypeObject *ZstdBufferSegmentType;
 
 typedef struct {
     PyObject_HEAD
@@ -341,7 +344,7 @@ typedef struct {
     int useFree;
 } ZstdBufferWithSegments;
 
-extern PyTypeObject ZstdBufferWithSegmentsType;
+extern PyTypeObject *ZstdBufferWithSegmentsType;
 
 /**
  * An ordered collection of BufferWithSegments exposed as a squashed collection.
@@ -364,7 +367,7 @@ typedef struct {
     Py_ssize_t *firstElements;
 } ZstdBufferWithSegmentsCollection;
 
-extern PyTypeObject ZstdBufferWithSegmentsCollectionType;
+extern PyTypeObject *ZstdBufferWithSegmentsCollectionType;
 
 int set_parameter(ZSTD_CCtx_params *params, ZSTD_cParameter param, int value);
 int set_parameters(ZSTD_CCtx_params *params,
@@ -385,5 +388,6 @@ BufferWithSegmentsCollection_length(ZstdBufferWithSegmentsCollection *);
 int cpu_count(void);
 size_t roundpow2(size_t);
 int safe_pybytes_resize(PyObject **obj, Py_ssize_t size);
+void set_io_unsupported_operation(void);
 
 #endif
